from typing import Annotated

source_code = Annotated[str, 'source_code']

markdown = Annotated[source_code, 'markdown']
md = markdown

html = Annotated[source_code, 'html']

django_html = Annotated[source_code, 'django_html']
django = django_html

django_txt = Annotated[source_code, 'django_txt']

jinja = Annotated[source_code, 'jinja']

jinja_html = Annotated[source_code, 'jinja_html']

css = Annotated[source_code, 'css']
style = css
styles = css

scss = Annotated[source_code, 'scss']

less = Annotated[source_code, 'less']

sass = Annotated[source_code, 'sass']

stylus = Annotated[source_code, 'stylus']

javascript = Annotated[source_code, 'javascript']
js = javascript

jsx = Annotated[source_code, 'jsx']
javascriptreact = jsx
react = jsx

typescript = Annotated[source_code, 'typescript']
ts = typescript

tsx = Annotated[source_code, 'tsx']
typescriptreact = tsx

coffeescript = Annotated[source_code, 'coffeescript']
coffee = coffeescript

sql = Annotated[source_code, 'sql']

json = Annotated[source_code, 'json']

yaml = Annotated[source_code, 'yaml']

graphql = Annotated[source_code, 'graphql']

xml = Annotated[source_code, 'xml']

python = Annotated[source_code, 'python']




from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()
    img_url = "https://raw.githubusercontent.com/samwillis/python-inline-source/main/sourcetypes/docs/examples.png"
    long_description = long_description.replace("(sourcetypes/docs/examples.png)", f"({img_url})")

setup(
    name='sourcetypes',
    version='0.0.2',
    author="Sam Willis",
    description="Python Source Code Types For Inline Syntax Highlighting",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/samwillis/python-inline-source/sourcetypes",
    py_modules=['sourcetypes'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.9',
    install_requires=[]
)
